Public Class GasCoByDefinition

	Inherits GasCorrelation

	Public Sub New()
		MyBase.New(pvtGasCo, "By Definition", "MPa-1")

		Input(pvtP, 0, 0, "MPa")
		Input(pvtT, 0, 0, "K")
		Input(pvtGasPseudoPcr, 0, 0, "MPa")
		Input(pvtGasPseudoTcr, 0, 0, "K")
		Input(pvtZFactorRC, 0, 0)
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtP), _
           f.Val(pvtT), _
           f.Val(pvtGasPseudoPcr), _
           f.Val(pvtGasPseudoTcr), _
           f.Val(pvtZFactorRC))

	End Function

	Public Function DoEval( _
	    ByVal P As Double, _
	    ByVal T As Double, _
	    ByVal Ppcr As Double, _
	    ByVal Tpcr As Double, _
	    ByVal Zf As Double) As Double
	    
	    Dim Tpr as Double = T / Tpcr
	    Dim Ppr as Double = P / Ppcr

		Dim rho_pr As Double = 0.27 * Ppr / Zf / Tpr
			    	    
		Dim A1# = 0.3265
		Dim A2# = -1.07
		Dim A3# = -0.5339
		Dim A4# = 0.01569
		Dim A5# = -0.05165
		Dim A6# = 0.5475
		Dim A7# = -0.7361
		Dim A8# = 0.1844
		Dim A9# = 0.1056
		Dim A10# = 0.6134
		Dim A11# = 0.721

		Dim dz_drho# = A1 + A2 / Tpr + A3 / Tpr ^ 3 + A4 / Tpr ^ 4 + A5 / Tpr ^ 5 _
			+ 2 * rho_pr * (A6 + A7 / Tpr + A8 / Tpr ^ 2) - 5 * A9 * rho_pr ^ 4 * (A7 / Tpr + A8 / Tpr ^ 2) _
			+ 2 * A10 * rho_pr / Tpr ^ 3 * (1 + A11 * rho_pr ^ 2 - A11 ^ 2 * rho_pr ^ 4) * Exp(- A11 * rho_pr ^ 2)
	
	    DoEval = 1 / P - 0.27 / (Zf ^ 2 * Tpr * Ppcr) * dz_drho / (1 + rho_pr * dz_drho / Zf)
	    
	End Function

End Class
