Public Class GasThermConductByShylov1985

	Inherits GasCorrelation

	Public Sub New()
		MyBase.New(pvtGasThermConduct, "Shylov (1985)", "W/(m*K)")

		Input(pvtP, 0.1, 20, "MPa")
		Input(pvtT, 263, 393, "K")
		Input(pvtGasMolMass, 0, 0, "g/mole")
		Input(pvtGasPseudoPcr, 0, 0, "MPa")
		Input(pvtGasPseudoTcr, 0, 0, "K")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtP), _
           f.Val(pvtGasPseudoPcr), _
           f.Val(pvtT), _
           f.Val(pvtGasPseudoTcr), _
           f.Val(pvtGasMolMass))

	End Function

	Public Function DoEval( _
	    ByVal P As Double, _
	    ByVal Ppcr As Double, _
	    ByVal T As Double, _
	    ByVal Tpcr As Double, _
	    ByVal Mg As Double) As Double
	    
	    Dim Ppr as Double = P / Ppcr
	    Dim Tpr as Double = T / Tpcr
	
	    DoEval = 0.001163 * (29.74 + 0.000193 * T ^ 2 + 0.0000005 * Mg ^ 4 - 1.061 * Mg) * (0.9965 + 0.3692 * Ppr / Tpr ^ 2 + 0.1337 * Ppr ^ 3 / Tpr ^ 7 + 0.006142 * Ppr ^ 2)
	    
	End Function

End Class
