Public Class GasViscByLucas

	Inherits GasCorrelation

	Public Sub New()
		MyBase.New(pvtGasVisc, "Lucas", "mPa*s")

		Input(pvtP, 0, 0, "Psia")
		Input(pvtT, 0, 0, "R")
		Input(pvtGasMolMass, 0, 0, "g/mole")
		Input(pvtGasPseudoPcr, 0, 0, "Psia")
		Input(pvtGasPseudoTcr, 0, 0, "R")
		Input(pvtGasViscOneAtm, 0, 0, "cPoise")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtP), _
           f.Val(pvtT), _
           f.Val(pvtGasMolMass), _
           f.Val(pvtGasPseudoPcr), _
           f.Val(pvtGasPseudoTcr), _
           f.Val(pvtGasViscOneAtm))

	End Function

	Public Function DoEval( _
	    ByVal P as Double, _
	    ByVal T as Double, _
	    ByVal Mg as Double, _
	    ByVal Ppcr as Double, _
	    ByVal Tpcr as Double, _
	    ByVal Ug_atm as Double) as Double
	
	    Dim Tpr# = T / Tpcr
	    Dim Ppr# = P / Ppcr
	    
	    Dim A1# = 1.245 * 10 ^(-3) * exp(5.1726 * Tpr ^ (-0.3286)) / Tpr
	    Dim A2# = A1 * (1.6553 * Tpr - 1.2723)
	    Dim A3# = 0.4489 * exp(3.0578 * Tpr ^ (-37.7332)) / Tpr
	    Dim A4# = 1.7368 * exp(2.231 * Tpr ^ (-7.6351)) / Tpr
	    Dim A5# = 0.9425 * exp(-0.1853 * Tpr ^ 0.4489)
	    
	    Dim Ug# = Ug_atm * (1 + A1 * ppr ^ 1.3088 / (A2 * ppr ^ A5 + (1 + A3 * ppr ^ A4) ^ (-1)))
	    Return Ug
	
	End Function

End Class
