Public Class ZFactorRCByBrillBeggsAndStanding

	Inherits GasCorrelation

	Public Sub New()
		MyBase.New(pvtZFactorRC, "Brill, Beggs and Standing (1974)", "")

		Input(pvtP, 0, 68.95, "MPa")
		Input(pvtT, 299.8166666667, 444.2611111111, "K")
		Input(pvtGasPseudoPcr, 0, 0, "MPa")
		Input(pvtGasPseudoTcr, 0, 0, "K")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtP), _
           f.Val(pvtGasPseudoPcr), _
           f.Val(pvtT), _
           f.Val(pvtGasPseudoTcr))

	End Function

	Public Function DoEval( _
	    ByVal P As Double, _
	    ByVal Ppcr As Double, _
	    ByVal T As Double, _        
	    ByVal Tpcr As Double) As Double
	
	    Dim Ppr as Double = P / Ppcr
	    Dim Tpr as Double = T / Tpcr
	
	    Dim d As Double
	    d = Exp(0.715 - 1.128 * Tpr + 0.42 * Tpr ^ 2)
	
	    Dim c As Double
	    c = 0.132 - 0.32 * Log10(Tpr)
	
	    Dim b As Double
	    b = Ppr * (0.62 - 0.23 * Tpr) + Ppr ^ 2 * (0.006 / (Tpr - 0.86) - 0.037) + 0.32 * Ppr ^ 6 / Exp(20.723 * (Tpr - 1))
	
	    Dim a As Double
	    a = 1.39 * Sqrt(Tpr - 0.92) - 0.36 * Tpr - 0.101
	
	    DoEval = a + (1 - a) * Exp(-b) + c * (Ppr ^ d)
	    
	End Function

End Class
