Public Class ZFactorRCByStandingAndKatz1942

	Inherits GasCorrelation

	Public Sub New()
		MyBase.New(pvtZFactorRC, "Standing and Katz (1942)", "")

		Input(pvtP, 0, 0, "MPa")
		Input(pvtT, 0, 0, "K")
		Input(pvtGasPseudoPcr, 0, 0, "MPa")
		Input(pvtGasPseudoTcr, 0, 0, "K")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtP), _
           f.Val(pvtGasPseudoPcr), _
           f.Val(pvtT), _
           f.Val(pvtGasPseudoTcr))

	End Function

	Public Function DoEval( _
	    ByVal P As Double, _
	    ByVal P_pcr As Double, _
	    ByVal T As Double, _
	    ByVal T_pcr As Double) As Double
	
	    Dim Ppr As Double = P / P_pcr
	    Dim Tpr As Double = T / T_pcr
	    
	    Dim A1# = 0.3265
	    Dim A2# = -1.07
	    Dim A3# = -0.5339
	    Dim A4# = 0.01569
	    Dim A5# = -0.05165
	    Dim A6# = 0.5475
	    Dim A7# = -0.7361
	    Dim A8# = 0.1844
	    Dim A9# = 0.1056
	    Dim A10# = 0.6134
	    Dim A11# = 0.721
	    
	    Dim rho_pr As Func(Of Double, Double) = Function(z) 0.27 * Ppr / z / Tpr
	    
	    Dim eq As Func(Of Double, Double) = Function(z) _
	    z - (1 + (A1 + A2 / Tpr + A3 / Tpr ^ 3 + A4 / Tpr ^ 4 + A5 / Tpr ^ 5) * rho_pr(z) _
	    + (A6 + A7 / Tpr + A8 / Tpr ^ 2) * rho_pr(z) ^ 2 - A9 * (A7 / Tpr + A8 / Tpr ^ 2) * rho_pr(z) ^ 5 _
	    + A10 * (1 + A11 * rho_pr(z) ^ 2) * (rho_pr(z) ^ 2 / Tpr ^ 3) * Math.Exp(-A11 * rho_pr(z) ^ 2))
	    
	    Dim zmin As Double = 0.0001
	    Const zmax As Double = 2
	    Dim tol As Double = 0.0001
	    Const itermax As Double = 100
	
	    return Solve(eq, zmin, zmax, tol, itermax)
	
	End Function

End Class
