Public Class ZFactorRCByDranchuk1974

	Inherits GasCorrelation

	Public Sub New()
		MyBase.New(pvtZFactorRC, "Dranchuk, Purvis and Robinson (1974)", "")

		Input(pvtP, 0, 0, "MPa")
		Input(pvtT, 0, 0, "K")
		Input(pvtGasPseudoPcr, 0, 0, "MPa")
		Input(pvtGasPseudoTcr, 0, 0, "K")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtP), _
           f.Val(pvtT), _
           f.Val(pvtGasPseudoPcr), _
           f.Val(pvtGasPseudoTcr))

	End Function

	Public Function DoEval( _
	    ByVal P as Double, _
	    ByVal T as Double, _
	    ByVal P_pcr as Double, _
	    ByVal T_pcr as Double) as Double
	
	    Dim Ppr As Double = P / P_pcr
	    Dim Tpr As Double = T / T_pcr
	    
	    Dim rho_pr As Func(Of Double, Double) = Function(z) 0.27 * Ppr / z / Tpr
	            
	    Dim A1# = 0.31506237
	    Dim A2# = -1.0467099
	    Dim A3# = -0.57832720
	    Dim A4# = 0.53530771
	    Dim A5# = -0.61232032
	    Dim A6# = -0.10488813
	    Dim A7# = 0.68157001
	    Dim A8# = 0.68446549

		Dim T1# = A1 + A2 / Tpr + A3 / Tpr ^ 3
		Dim T2# = A4 + A5 / Tpr
		Dim T3# = A5 * A6 / Tpr
		Dim T4# = A7 / Tpr ^ 3
		
		Dim eq As Func(Of Double, Double) = Function(z) _
		z - (1 + T1 * rho_pr(z) + T2 * rho_pr(z) ^ 2 + T3 * rho_pr(z) ^ 5 _
		+ T4 * (1 + A8 * rho_pr(z) ^ 2) * rho_pr(z) ^ 2 * exp(- A8 * rho_pr(z) ^ 2))
		
		Dim zmin As Double = 0.0001
		Const zmax As Double = 2
		Dim tol As Double = 0.0001
		Const itermax As Double = 100
		
		return Solve(eq, zmin, zmax, tol, itermax)
		
	End Function
	
End Class
