Public Class ZFactorRCByDranchuk1974

	Inherits GasCorrelation

	Public Sub New()
		MyBase.New(pvtZFactorRC, "Dranchuk, Abu-Kassem (1975)", "")

		Input(pvtP, 0, 0, "MPa")
		Input(pvtT, 0, 0, "K")
		Input(pvtGasPseudoPcr, 0, 0, "MPa")
		Input(pvtGasPseudoTcr, 0, 0, "K")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtP), _
           f.Val(pvtT), _
           f.Val(pvtGasPseudoPcr), _
           f.Val(pvtGasPseudoTcr))

	End Function

	Public Function DoEval( _
	    ByVal P as Double, _
	    ByVal T as Double, _
	    ByVal P_pcr as Double, _
	    ByVal T_pcr as Double) as Double
	
	    Dim Ppr As Double = P / P_pcr
	    Dim Tpr As Double = T / T_pcr
	    
	    Dim rho_pr As Func(Of Double, Double) = Function(z) 0.27 * Ppr / z / Tpr
	            
	    Dim A1# = 0.3265
	    Dim A2# = -1.07
	    Dim A3# = -0.5339
	    Dim A4# = 0.01569
	    Dim A5# = -0.05165
	    Dim A6# = 0.5475
	    Dim A7# = -0.7361
	    Dim A8# = 0.1844
		Dim A9# = 0.1056
		Dim A10# = 0.6134
		Dim A11# = 0.7210

		Dim R1# = A1 + A2 / Tpr + A3 / Tpr ^ 3 + A4 / Tpr ^ 4 + A5 / Tpr ^ 5
		Dim R3# = A6 + A7 /  Tpr + A8 / Tpr ^ 2
		Dim R4# = A9 * (A7 / Tpr + A8 / Tpr ^ 2)
		Dim R5# = A10 / Tpr ^ 3
		
		Dim eq As Func(Of Double, Double) = Function(z) _
		z - (1 + R1 * rho_pr(z) + R3 * rho_pr(z) ^ 2 - R4 * rho_pr(z) ^ 5 _
		+ R5 * (1 + A11 * rho_pr(z) ^ 2) * rho_pr(z) ^ 2 * exp(- A11 * rho_pr(z) ^ 2))
		
		Dim zmin As Double = 0.0001
		Const zmax As Double = 2
		Dim tol As Double = 0.0001
		Const itermax As Double = 100
		
		return Solve(eq, zmin, zmax, tol, itermax)
		
	End Function
	
End Class
