Public Class ZFactorRCByHallYarborough1973

	Inherits GasCorrelation

	Public Sub New()
		MyBase.New(pvtZFactorRC, "Hall & Yarborough (1973)", "")

		Input(pvtP, 13.8, 94.3, "MPa")
		Input(pvtT, 310.9, 425.9, "K")
		Input(pvtGasPseudoPcr, 0, 0, "MPa")
		Input(pvtGasPseudoTcr, 0, 0, "K")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtP), _
           f.Val(pvtT), _
           f.Val(pvtGasPseudoPcr), _
           f.Val(pvtGasPseudoTcr))

	End Function

	Public Function DoEval( _
	    ByVal P as Double, _
	    ByVal T as Double, _
	    ByVal Ppcr as Double, _
	    ByVal Tpcr as Double) as Double
	    
	    Dim tt# = Tpcr / T
	    Dim Ppr# = P / Ppcr
	    
	    Dim X1# = 14.76 * tt - 9.76 * tt ^ 2 + 4.58 * tt ^ 3
	    Dim X2# = 90.7 * tt - 242.2 * tt ^ 2 + 42.4 * tt ^ 3
	    Dim X3# = 1.18 + 2.82 * tt
	    
	    Dim Y As Func(Of Double, Double) = Function(z) 0.06125 * tt * Ppr / z * exp(- 1.2 * (1 - tt) ^ 2)
	
	    Dim eq As Func(Of Double, Double) = Function(z) _
	        z - ((1 + Y(z) + Y(z) ^ 2 + Y(z) ^ 3) / (1 - Y(z)) ^ 3 - X1 * Y(z) + X2 * Y(z) ^ X3)
	    
	    Dim zmin As Double = 0.0001
	    Const zmax As Double = 2
	    Dim tol As Double = 0.0001
	    Const itermax As Double = 100
	
	    return Solve(eq, zmin, zmax, tol, itermax)
	
	End Function

End Class
