Public Class ZFactorRCByNX19ModГОСТ303191

	Inherits GasCorrelation

	Public Sub New()
		MyBase.New(pvtZFactorRC, "NX19 mod. (30319.2-96)", "")

		Input(pvtGasSG, 0.66, 1.05)
		Input(pvtP, 0.1, 12, "MPa")
		Input(pvtT, 250, 340, "K")
		Input(pvtN2, 0, 15)
		Input(pvtCO2, 0, 15)
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtGasSG), _
           f.Val(pvtP), _
           f.Val(pvtT), _
           f.Val(pvtCO2), _
           f.Val(pvtN2))

	End Function

	Public Function DoEval( _
	    ByVal gasSG as Double, _
	    ByVal P as Double, _
	    ByVal T as Double, _
	    ByVal N2 as Double, _
	    ByVal CO2 as Double) as Double
	
	    Dim xa# = N2
	    Dim xy# = CO2
	        
	    Dim rho# = 1.205 * gasSG
	    
	    '(17) ГОСТ 30319.1 (формула (48))
	    Dim p_pcr# = 2.9585 * (1.608 - 0.05994 * rho + xy - 0.392 * xa)
	    
	    '(18) ГОСТ 30319.1 (формула (49))
	    Dim T_pcr# = 88.25 * (0.9915 + 1.759 * rho - xy - 1.681 * xa)
	    
	    '(15)
	    Dim pa# = 0.6714 * (p / p_pcr) + 0.0147
	    
	    '(16)
	    Dim Ta# = 0.71892 * (T / T_pcr) + 0.0007
	    
	    '(11)
	    Dim O1# = Ta ^ 5 / (Ta ^ 2 * (6.60756 * Ta - 4.42646) + 3.22706)
	    
	    '(10)
	    Dim O0# = (Ta ^ 2 * (1.77218 - 0.8879 * Ta) + 0.305131) * O1 / Ta ^ 4
	    
	    Dim dTa# = Ta - 1.09
	    
	    Dim F# = 0
	    
	    Dim tmp# = 75 * 10 ^ (-5) * pa ^ 2.3
	    if 0 <= pa and pa <= 2 and 0 <= dTa and dTa <= 0.3 then
	        '(12)
	        F = tmp / exp(20 * dTa) + 11 * 10 ^ (-4) * dTa ^ 0.5 * (pa * (2.17 - pa + 1.4 * dTa ^ 0.5)) ^ 2
	    else
	        tmp *= 2 - exp(20 * dTa)
	        if 0 <= pa and pa < 1.3 and - 0.25 <= dTa and dTa < 0 then
	            '(13)
	            F = tmp + 1.317 * pa * (1.69 - pa ^ 2) * dTa ^ 4
	        elseif 1.3 <= pa and pa < 2 and - 0.21 <= dTa and dTa < 0 then
	            '(14)
	            F = tmp + 0.455 * (1.3 - pa) * (1.69 * 2 ^ 1.25 - pa ^ 2) * _
	                (dTa * (0.03249 + 18.028 * dTa ^ 2) + _  
	                dTa ^ 2 * (2.0167 + dTa ^ 2 * (42.844 + 200 * dTa ^ 2)))
	        end if
	    end if
	    
	    '(8)
	    Dim B0# = O0 * (O1 - O0 ^ 2) + 0.1 * O1 * pa * (F - 1)
	    
	    '(9)
	    Dim B1# = 2 * O1 / 3 - O0 ^ 2
	    
	    '(7)
	    Dim B2# = (B0 + (B0 ^ 2 + B1 ^ 3) ^ 0.5) ^ (1 / 3)
	    
	    '(6)
	    Dim z# = (1 + 0.00132 / Ta ^ 3.25) ^ 2 / (B1 / B2 - B2 + O0) * pa / 10      
	    Return z
	
	End Function

End Class
