Public Class BoByDindorukChristman2001

	Inherits OilCorrelation

	Public Sub New()
		MyBase.New(pvtBo, "Dindoruk-Christman (2001)", "m3/m3")

		Input(pvtOilSG, 0, 0)
		Input(pvtGasSG, 0, 0)
		Input(pvtP, 0, 0, "Psia")
		Input(pvtT, -459.67, -459.67, "F")
		Input(pvtPbub, 0, 0, "Psia")
		Input(pvtRs, 0, 0, "std scf/bbl")
		Input(pvtOilCo, 0, 0, "Psia-1")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtRs), _
           f.Val(pvtOilSG), _
           f.Val(pvtGasSG), _
           f.Val(pvtT), _
           f.Val(pvtOilCo), _
           f.Val(pvtPbub), _
           f.Val(pvtP))

	End Function

	Public Function DoEval( _
	    ByVal Rs as Double, _
	    ByVal oilSG as Double, _
	    ByVal gasSG as Double, _
	    ByVal T as Double, _
	    ByVal oilCo as Double, _
	    ByVal Pb as Double, _
	    ByVal P as Double) as Double
	
	    Dim a1# = 2.510755
	    Dim a2# = -4.852538
	    Dim a3# = 1.1835*10
	    Dim a4# = 1.365428*10^5
	    Dim a5# = 2.25288
	    Dim a6# = 1.00719*10
	    Dim a7# = 4.450849*10^(-1)
	    Dim a8# = 5.352624
	    Dim a9# = -6.309052*10^(-1)
	    Dim a10# = 9.000749*10^(-1)
	    Dim a11# = 9.871766*10^(-1)
	    Dim a12# = 7.865146*10^(-4)
	    Dim a13# = 2.689173*10^(-6)
	    Dim a14# = 1.100001*10^(-5)
	
	    Dim A# = (Rs ^ a1 * gasSG ^ a2 / oilSG ^ a3 + a4 * (T - 60) ^ a5 + a6 * Rs) ^ a7 _
	        / (a8 + 2 * Rs ^ a9 / gasSG ^ a10 * (T - 60)) ^ 2
	        
	    Dim Bob# = a11 + a12 * A + a13 * A^2 + a14 * (T - 60) * API(oilSG) / gasSG
	
	    If P < Pb Then
	        DoEval = Bob
	    Else
	        DoEval = Bob * Exp(oilCo * (Pb - P))
	    End If
	    
	End Function

End Class
