Public Class BoByGimatudinov

	Inherits OilCorrelation

	Public Sub New()
		MyBase.New(pvtBo, "Gimatudinov", "m3/m3")

		Input(pvtOilSG, 0, 0)
		Input(pvtGasSG, 0, 0)
		Input(pvtP, 0, 0, "MPa")
		Input(pvtT, 0, 0, "K")
		Input(pvtPbub, 0, 0, "MPa")
		Input(pvtRs, 0, 0, "std m3/m3")
		Input(pvtOilCo, 0, 0, "MPa-1")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtOilSG), _
           f.Val(pvtRs), _
           f.Val(pvtOilCo), _
           f.Val(pvtGasSG), _
           f.Val(pvtPbub), _
           f.Val(pvtP), _
           f.Val(pvtT))

	End Function

	Public Function DoEval( _
	    ByVal oilSG As Double, _
	    ByVal Rs As Double, _
	    ByVal oilCo As Double, _
	    ByVal gasSG As Double, _
	    ByVal Pb As Double, _
	    ByVal P As Double, _
	    ByVal T As Double) As Double
	
	    Dim rhoGsc# = 1.205 * gasSG
	
	    Dim lambda As Double
	    lambda = 0.001 * (4.3 + 0.858 * rhoGsc + 0.0052 * (1 - 0.0015 * Rs) * Rs - 3.54 * oilSG)
	
	    Dim alpha As Double
	    If (0.78 <= oilSG And oilSG <= 0.86) Then
	        alpha = 0.001 * (3.083 - 2.638 * oilSG)
	    End If
	    If (0.86 <= oilSG And oilSG <= 0.96) Then
	        alpha = 0.001 * (2.513 - 1.975 * oilSG)
	    End If
	
	    Dim Bob As Double = 1 + lambda * Rs + alpha * (T - 293) - oilCo * P
	
	    If P < Pb Then
	        DoEval = Bob
	    Else
	        DoEval = Bob * Exp(oilCo * (Pb - P))
	    End If
	
	End Function

End Class
