Public Class BoByStanding1947

	Inherits OilCorrelation

	Public Sub New()
		MyBase.New(pvtBo, "Standing (1947)", "m3/m3")

		Input(pvtOilSG, 0.7245, 0.9561)
		Input(pvtGasSG, 0.59, 0.95)
		Input(pvtP, 0, 0, "MPa")
		Input(pvtT, 311, 399, "K")
		Input(pvtPbub, 0.896, 48.27, "MPa")
		Input(pvtRs, 3.6, 256.6, "std m3/m3")
		Input(pvtOilCo, 0.0002, 0.002, "MPa-1")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtOilSG), _
           f.Val(pvtGasSG), _
           f.Val(pvtPbub), _
           f.Val(pvtRs), _
           f.Val(pvtOilCo), _
           f.Val(pvtP), _
           f.Val(pvtT))

	End Function

	Public Function DoEval( _
	    ByVal oilSG As Double, _
	    ByVal gasSG As Double, _
	    ByVal Pb As Double, _
	    ByVal Rs As Double, _
	    ByVal oilCo As Double, _
	    ByVal P As Double, _
	    ByVal T As Double) As Double
	
	    Dim f As Double
	    Dim Bob As Double
	
	    f = 5.615 * Rs * (gasSG / oilSG) ^ 0.5 + 2.25 * T - 575
	    Bob = 0.972 + 0.000147 * f ^ 1.175
	
	    If P < Pb Then
	        DoEval = Bob
	    Else
	        DoEval = Bob * Exp(oilCo * (Pb - P))
	    End If
	
	End Function

End Class
