Public Class BoByTagintseva1985LightOils

	Inherits OilCorrelation

	Public Sub New()
		MyBase.New(pvtBo, "Tagintseva (1985, light oils)", "m3/m3")

		Input(pvtOilSG, 0.802, 0.957)
		Input(pvtP, 0, 0, "Bar")
		Input(pvtPbub, 0, 0, "Bar")
		Input(pvtRs, 39, 253, "std m3/m3")
		Input(pvtOilCo, 0, 0, "MPa-1")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtOilSG), _
           f.Val(pvtRs), _
           f.Val(pvtP), _
           f.Val(pvtPbub), _
           f.Val(pvtOilCo))

	End Function

	Public Function DoEval( _
	    ByVal oilSG As Double, _
	    ByVal Rs As Double, _
	    ByVal P As Double, _
	    ByVal Pb As Double, _
	    ByVal Co As Double) As Double
	
	    Co *= CoMPa2bar
	
	    Dim Prsv As Double = Min(P, Pb)
	    Dim logPres As Double = Log(Prsv)
	
	    Dim c0 As Double
	    c0 = Exp(0.00053 - 0.134747 * logPres + 0.135779 * logPres ^ 2 - 0.014445 * logPres ^ 3)
	
	    Dim c1 As Double
	    c1 = -0.958 + 1.095 * logPres - 0.4396 * logPres ^ 2 + 0.0383 * logPres ^ 3
	
	    Dim c2 As Double
	    c2 = 0.00158 - 0.0309 / Prsv + 0.835 / Prsv ^ 2 - 4.246 / Prsv ^ 3
	
	    Dim Bob As Double
	    Bob = c0 + c1 * oilSG + c2 * Rs
	
	    If P <= Pb Then
	        DoEval = Bob
	    Else
	        DoEval = Bob * Exp(Co * (Pb - P))
	    End If
	
	End Function

End Class
