Public Class BoByVasquezAndBeggs1980

	Inherits OilCorrelation

	Public Sub New()
		MyBase.New(pvtBo, "Vasquez and Beggs (1980)", "m3/m3")

		Input(pvtOilSG, 0.7416, 0.9639)
		Input(pvtGasSG, 0.511, 1.35)
		Input(pvtP, 0, 0, "MPa")
		Input(pvtT, 297, 419, "K")
		Input(pvtPbub, 0, 0, "MPa")
		Input(pvtRs, 0, 396, "std m3/m3")
		Input(pvtOilCo, 0, 0, "MPa-1")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtOilSG), _
           f.Val(pvtGasSG), _
           f.Val(pvtRs), _
           f.Val(pvtT), _
           f.Val(pvtP), _
           f.Val(pvtPbub), _
           f.Val(pvtOilCo))

	End Function

	Public Function DoEval( _
	    ByVal oilSG As Double, _
	    ByVal gasSG As Double, _
	    ByVal Rs As Double, _
	    ByVal T As Double, _
	    ByVal P As Double, _
	    ByVal Pb As Double, _
	    ByVal oilCo As Double) As Double
	
	    Dim C1#
	    Dim C2#
	    Dim C3#
	    
	    If oilSG < 0.876 Then
	        C1 = 0.002593
	        C2 = 0.000011
	        C3 = 0.000000007423
	    Else
	        C1 = 0.002597
	        C2 = 0.00001751
	        C3 = -0.0000001005
	    End If
	
	    oilSG = API(oilSG)
	
	    Dim f# = oilSG / gasSG * (1.8 * T - 520)
	
	    Dim Bob# = 1 + C1 * Rs + f * (C2 + C3 * Rs)
	
	    If P < Pb Then
	        DoEval = Bob
	    Else
	        DoEval = Bob * Exp(oilCo * (Pb - P))
	    End If
	
	End Function

End Class
