Public Class OilCoByVasquezAndBeggs1980HeavyOilsPPb

	Inherits OilCorrelation

	Public Sub New()
		MyBase.New(pvtOilCo, "Vasquez and Beggs (1980, heavy oils, P > Pb)", "MPa-1")

		Input(pvtOilSG, 0.92, 1)
		Input(pvtGasSG, 0, 0)
		Input(pvtP, 0.9, 65.6, "MPa")
		Input(pvtT, -459.67, -459.67, "F")
		Input(pvtSepP, 0.4, 3.9, "MPa")
		Input(pvtSepT, 76.73, 150.53, "F")
		Input(pvtPbub, 0.1, 41.75, "MPa")
		Input(pvtRs, 0, 396, "std m3/m3")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtOilSG), _
           f.Val(pvtGasSG), _
           f.Val(pvtSepP), _
           f.Val(pvtSepT), _
           f.Val(pvtPbub), _
           f.Val(pvtRs), _
           f.Val(pvtP), _
           f.Val(pvtT))

	End Function

	Public Function DoEval( _
	    ByVal oilSG As Double, _
	    ByVal gasSG As Double, _
	    ByVal sepP As Double, _
	    ByVal sepT As Double, _
	    ByVal Pb As Double, _
	    ByVal Rs As Double, _
	    ByVal P As Double, _
	    ByVal T As Double) As Double
	
	    If Not (P > Pb) Then
	        'Exit Function
	    End If
	
	    oilSG = API(oilSG)
	
	    Dim gcorr# = gasSG * (1 + 0.5912 * oilSG * sepT * Log10(sepP / 0.7909) * 0.0001)
	
	    DoEval = (-2841.8 + 16.46 * Rs + 25.5439 * T - _
	        1230.5 * gcorr + 41.91 * oilSG) / (P * 100000.0#)
	
	End Function

End Class
