Public Class OilDensRCByMcCain1991

	Inherits OilCorrelation

	Public Sub New()
		MyBase.New(pvtOilDensRC, "McCain (1991)", "kg/m3")

		Input(pvtOilSG, 0.7245, 0.9561)
		Input(pvtGasSG, 0.59, 0.95)
		Input(pvtP, 0, 0, "MPa")
		Input(pvtPbub, 0, 0, "MPa")
		Input(pvtRs, 0, 0, "std m3/m3")
		Input(pvtOilCo, 0, 0, "MPa-1")
		Input(pvtBo, 0, 0, "m3/m3")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtOilSG), _
           f.Val(pvtGasSG), _
           f.Val(pvtPbub), _
           f.Val(pvtRs), _
           f.Val(pvtOilCo), _
           f.Val(pvtBo), _
           f.Val(pvtP))

	End Function

	Public Function DoEval( _
	    ByVal oilSG As Double, _
	    ByVal gasSG As Double, _
	    ByVal Pb As Double, _
	    ByVal Rs As Double, _
	    ByVal oilCo As Double, _
	    ByVal Bo As Double, _
	    ByVal P As Double) As Double
	
	    Dim rhoSC As Double
	    rhoSC = 1000 * oilSG + 1.2068255 * Rs * gasSG
	
	    DoEval = rhoSC / Bo
	
	    If Pb <= P Then
	        DoEval *= Exp(oilCo * (P - Pb))
	    End If
	
	End Function

End Class
