Public Class OilDensRCByShylov1985

	Inherits OilCorrelation

	Public Sub New()
		MyBase.New(pvtOilDensRC, "Shylov (1985)", "kg/m3")

		Input(pvtOilSG, 0, 0)
		Input(pvtGasSG, 0, 0)
		Input(pvtP, 0.1, 35, "MPa")
		Input(pvtT, 273, 408, "K")
		Input(pvtPbub, 0, 0, "MPa")
		Input(pvtRs, 0, 0, "std m3/m3")
		Input(pvtOilCo, 0, 0, "MPa-1")
		Input(pvtBo, 0, 0, "m3/m3")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtRs), _
           f.Val(pvtBo), _
           f.Val(pvtOilSG), _
           f.Val(pvtGasSG), _
           f.Val(pvtP), _
           f.Val(pvtT), _
           f.Val(pvtPbub), _
           f.Val(pvtOilCo))

	End Function

	Public Function DoEval( _
	    ByVal Rs As Double, _
	    ByVal Bo As Double, _
	    ByVal oilSG As Double, _
	    ByVal gasSG As Double, _
	    ByVal P As Double, _
	    ByVal T As Double, _
	    ByVal Pb As Double, _
	    ByVal oilCo As Double) As Double
	
	    Dim rhoOsc# = 1000 * oilSG
	    Dim rhoGsc# = 1.205 * gasSG
	
	    Dim DensAtPb As Double = Exp(4.12 - 0.4299 * Bo - 0.000002581 * Rs + 0.0003649 * P - 0.0007141 * T + 0.4904 * Log(rhoOsc) - 0.01346 * rhoGsc)
	
	    If P < Pb Then
	        DoEval = DensAtPb
	    Else
	        DoEval = DensAtPb * Exp(oilCo * (P - Pb))
	    End If
	
	End Function

End Class
