Public Class OilGasTensByBakerAndSwerdloff1956

	Inherits OilCorrelation

	Public Sub New()
		MyBase.New(pvtOilGasTens, "Baker and Swerdloff (1956)", "N/m")

		Input(pvtOilSG, 0, 0)
		Input(pvtP, 0, 0, "MPa")
		Input(pvtT, 0, 0, "K")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtOilSG), _
           f.Val(pvtP), _
           f.Val(pvtT))

	End Function

	Public Function DoEval( _
	    ByVal oilSG As Double, _
	    ByVal P As Double, _
	    ByVal T As Double) As Double
	
	    Dim sigmaT293 As Double
	    Dim sigmaT310 As Double
	    Dim sigmaT As Double
	
	    sigmaT293 = 0.07280865 - 0.03637965 / oilSG
	    sigmaT310 = 0.07137965 - 0.03637965 / oilSG
	
	    Select Case T
	        Case Is < 293.15
	            sigmaT = sigmaT293
	        Case 293.15 To 310.93
	            sigmaT = sigmaT293 - (0.05625 * T - 16.4896875) * (sigmaT293 - sigmaT310)
	        Case Else
	            sigmaT = sigmaT310
	    End Select
	
	    DoEval = sigmaT * (1 - 0.225356857 * P ^ 0.45)
	
	End Function

End Class
