Public Class OilHeatCapacityByShylov1985less293

	Inherits OilCorrelation

	Public Sub New()
		MyBase.New(pvtOilHeatCapacity, "Shylov (1985, T freezing < 293K)", "J/(kg*K)")

		Input(pvtOilSG, 0, 0)
		Input(pvtT, 0, 200, "C")
		Input(pvtOilMolarMass, 0, 0, "g/mole")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtOilSG), _
           f.Val(pvtOilMolarMass), _
           f.Val(pvtT))

	End Function

	Public Function DoEval( _
	    ByVal oilSG As Double, _
	    ByVal Mo As Double, _
	    ByVal T As Double) As Double
	
		Dim T0# = 20
	    Dim A0# = 2.3504
	    Dim A1# = 4.6588
	    Dim A2# = -1.3406
	    Dim A3# = -5.344
	    Dim B0# = 15.73
	    Dim B1# = -0.00006114
	    Dim B2# = 8.645
	    Dim B3# = -114.24
	    Dim AA0# = 1.218
	    Dim AA1# = 0.358
	
	    Dim nDT0# = AA0 + AA1 * oilSG ^ 2	
	    Dim Cpt0# = 1000 * (A0 + A1 * Log10(Mo) ^ (1 / 3) + A2 * Log10(Mo) ^ (1 / 3) / oilSG + A3 * oilSG)	
	    Dim alpha# = 0.001 * (B0 + B1 * Mo + B2 * oilSG ^ 3 + B3 * Log10(nDT0))
	
	    return Cpt0 * (1 + alpha * (T - T0))
	    
	End Function

End Class
