Public Class OilWaterTensByRN

	Inherits OilCorrelation

	Public Sub New()
		MyBase.New(pvtOilWaterTens, "RN", "N/m")

		Input(pvtOilSG, 0, 0)
		Input(pvtP, 0, 0, "MPa")
		Input(pvtT, 0, 0, "K")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtOilSG), _
           f.Val(pvtP), _
           f.Val(pvtT))

	End Function

	Public Function DoEval( _
	    ByVal oilSG As Double, _
	    ByVal P As Double, _
	    ByVal T As Double) As Double
	
	    Dim C# = 1 - 0.235 * P ^ 0.45
	    Dim sigmaT As Double
	
	    If T > 311 Then
	        sigmaT = 0.07131 - 0.03638 / oilSG
	    Else
	        sigmaT = (0.074581 - 0.03638 / oilSG - 0.000026 * T)
	    End If
	
	    Dim IFT_OilGas# = C * sigmaT
	    Dim IFT_WaterGas# = 0.001 * (75 - 6.296 * P ^ 0.349 - (1.8 * T - 534) * (22 - 6.296 * P ^ 0.349 + 2.5256 * P ^ 0.637) / 206)
	
	    DoEval = IFT_WaterGas - IFT_OilGas
	
	End Function

End Class
