Public Class PbubByLasater1958

	Inherits OilCorrelation

	Public Sub New()
		MyBase.New(pvtPbub, "Lasater (1958)", "MPa")

		Input(pvtRsb, 0.5, 523, "std m3/m3")
		Input(pvtOilSG, 0.775, 0.947)
		Input(pvtGasSG, 0.574, 1.223)
		Input(pvtT, 301, 406, "K")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtOilSG), _
           f.Val(pvtGasSG), _
           f.Val(pvtRsb), _
           f.Val(pvtT))

	End Function

	Public Function DoEval( _
	    ByVal oilSG As Double, _
	    ByVal gasSG As Double, _
	    ByVal Rsb As Double, _
	    ByVal T As Double) As Double
	
	    Dim Mo As Double
	    If oilSG <= 0.825 Then
	        Mo = (0.109 / oilSG - 0.101) ^ (-1.562)
	    Else
	        Mo = 1945 - 1415 / oilSG
	    End If
	
	    Dim yg As Double
	    yg = 0.0148 * Rsb / (0.0148 * Rsb + 1000 * oilSG / Mo)
	
	    Dim pf As Double
	    If yg <= 0.6 Then
	        pf = 8.427 * Exp(2.78 * yg) - 4.01
	    Else
	        pf = 102.51 * yg ^ 3.56 + 24.2
	    End If
	
	    DoEval = pf * 1.8 * T / (1000 * gasSG)
	
	End Function

End Class
