Public Class PbubByVasquezAndBeggs1980

	Inherits OilCorrelation

	Public Sub New()
		MyBase.New(pvtPbub, "Vasquez and Beggs (1980)", "MPa")

		Input(pvtRsb, 0, 396, "std m3/m3")
		Input(pvtOilSG, 0.741, 0.964)
		Input(pvtGasSG, 0, 1)
		Input(pvtT, 297, 419, "K")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtOilSG), _
           f.Val(pvtGasSG), _
           f.Val(pvtRsb), _
           f.Val(pvtT))

	End Function

	Public Function DoEval( _
	    ByVal oilSG As Double, _
	    ByVal gasSG As Double, _
	    ByVal Rsb As Double, _
	    ByVal T As Double) As Double
	
	    Dim C1 As Double
	    Dim C2 As Double
	    Dim C3 As Double
	    Dim C4 As Double
	    
		If oilSG < 0.876 Then
	        C1 = 0.0003204
	        C2 = 0.8425
	        C3 = 1881.24
	        C4 = 1748.29
	    Else
	        C1 = 0.0007803
	        C2 = 0.9143
	        C3 = 2022.19
	        C4 = 1879.28
	    End If
	
	    Dim denom As Double
	    denom = C1 * gasSG * Exp(C3 / (oilSG * T) - C4 / T)
	
	    DoEval = 0.001 * (Rsb / denom) ^ C2
	
	End Function

End Class
