Public Class RsByVelarde

	Inherits OilCorrelation

	Public Sub New()
		MyBase.New(pvtRs, "Velarde", "std m3/m3")

		Input(pvtRsb, 0, 0, "std m3/m3")
		Input(pvtOilSG, 0, 0)
		Input(pvtGasSG, 0, 0)
		Input(pvtP, 0.1, 30, "MPa")
		Input(pvtT, -459.67, -459.67, "F")
		Input(pvtPbub, 0, 0, "MPa")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtP), _
           f.Val(pvtPbub), _
           f.Val(pvtGasSG), _
           f.Val(pvtT), _
           f.Val(pvtOilSG), _
           f.Val(pvtRsb))

	End Function

	Public Function DoEval( _
	    ByVal P As Double, _
	    ByVal Pb As Double, _
	    ByVal gasSG As Double, _
	    ByVal T As Double, _
	    ByVal oilSG As Double, _
	    ByVal Rsb As Double) As Double
	
	    If P >= Pb Then
	        DoEval = Rsb
	    Else
	        oilSG = API(oilSG)
	
	        Dim a_0 As Double
	        Dim a_1 As Double
	        Dim a_2 As Double
	        Dim a_3 As Double
	        Dim a_4 As Double
	        Dim A1 As Double
	
	        a_0 = 1.8653 * 10 ^ (-4)
	        a_1 = 1.672608
	        a_2 = 0.92987
	        a_3 = 0.247235
	        a_4 = 1.056052
	
	        A1 = a_0 * gasSG ^ a_1 * oilSG ^ a_2 * T ^ a_3 * Pb ^ a_4
	
	        Dim b_0 As Double
	        Dim b_1 As Double
	        Dim b_2 As Double
	        Dim b_3 As Double
	        Dim b_4 As Double
	        Dim A2 As Double
	
	        b_0 = 0.1004
	        b_1 = -1.00475
	        b_2 = 0.337711
	        b_3 = 0.132795
	        b_4 = 0.302065
	
	        A2 = b_0 * gasSG ^ b_1 * oilSG ^ b_2 * T ^ b_3 * Pb ^ b_4
	
	        Dim c_0 As Double
	        Dim c_1 As Double
	        Dim c_2 As Double
	        Dim c_3 As Double
	        Dim c_4 As Double
	        Dim A3 As Double
	
	        c_0 = 0.9167
	        c_1 = -1.48548
	        c_2 = -0.164741
	        c_3 = -0.09133
	        c_4 = 0.047094
	
	        A3 = c_0 * gasSG ^ c_1 * oilSG ^ c_2 * T ^ c_3 * Pb ^ c_4
	
	        Const stdPres# = 0.1
	
	        Dim Pr As Double
	        Pr = (P - stdPres) / Pb
	
	        Dim Rsr As Double
	        Rsr = A1 * Pr ^ A2 + (1 - A1) * Pr ^ A3
	
	        DoEval = Rsr * Rsb
	        
	    End If
	
	End Function

End Class
