Public Class RsbByLasater1958

	Inherits OilCorrelation

	Public Sub New()
		MyBase.New(pvtRsb, "Lasater (1958)", "std m3/m3")

		Input(pvtOilSG, 0.775, 0.947)
		Input(pvtGasSG, 0.574, 1.223)
		Input(pvtT, 301, 406, "K")
		Input(pvtPbub, 0.331, 39.85, "MPa")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtOilSG), _
           f.Val(pvtGasSG), _
           f.Val(pvtPbub), _
           f.Val(pvtT))

	End Function

	Public Function DoEval( _
	    ByVal oilSG As Double, _
	    ByVal gasSG As Double, _
	    ByVal Pb As Double, _
	    ByVal T As Double) As Double
	
	    Dim Mo As Double
	    If oilSG <= 0.825 Then
	        Mo = 1945 - 1451 / oilSG
	    Else
	        Mo = (0.109 / oilSG - 0.101) ^ (-1.562)
	    End If
	
	    Dim pressureFactor# = Pb * gasSG / T
	
	    Dim yg As Double
	    If pressureFactor < 40.7 Then
	        yg = 0.359 * Log(118.7 * pressureFactor / 1.8 + 0.476)
	    Else
	        yg = (9.8 * pressureFactor / 1.8 - 0.236) ^ 0.281
	    End If
	
	    DoEval = 23643 * oilSG * yg / (Mo * (1 - yg))
	
	End Function

End Class
