Public Class RsbByVasquezAndBeggs1980

	Inherits OilCorrelation

	Public Sub New()
		MyBase.New(pvtRsb, "Vasquez and Beggs (1980)", "std m3/m3")

		Input(pvtOilSG, 0.741, 0.964)
		Input(pvtGasSG, 0.574, 1.223)
		Input(pvtT, 297, 419, "K")
		Input(pvtSepP, 0.4, 3.9, "MPa")
		Input(pvtSepT, 76.73, 150.53, "F")
		Input(pvtPbub, 14.5032632342, 6055.1124002901, "Psia")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtOilSG), _
           f.Val(pvtGasSG), _
           f.Val(pvtSepP), _
           f.Val(pvtSepT), _
           f.Val(pvtPbub), _
           f.Val(pvtT))

	End Function

	Public Function DoEval( _
	    ByVal oilSG As Double, _
	    ByVal gasSG As Double, _
	    ByVal sepP As Double, _
	    ByVal sepT As Double, _
	    ByVal Pb As Double, _
	    ByVal T As Double) As Double
	
	    oilSG = API(oilSG)
	
	    Dim gcorr# = gasSG * (1 + 0.5912 * oilSG * sepT * Log10(sepP / 0.7909) * 0.0001)
	
	    DoEval = gcorr / 313.348 * Pb ^ 1.2057 * 10 ^ (10.9267 * oilSG / (1.8 * T))
	
	End Function

End Class
