Public Class SepGORByStandingAndKatz

	Inherits OilCorrelation

	Public Sub New()
		MyBase.New(pvtSepGOR, "Standing and Katz", "std m3/m3")

		Input(pvtOilSG, 0.87, 0.92)
		Input(pvtSepP, 0.07, 41.37, "MPa")
		Input(pvtSepT, 276, 419, "K")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtOilSG), _
           f.Val(pvtSepP), _
           f.Val(pvtSepT))

	End Function

	Public Function DoEval( _
	    ByVal oilSG As Double, _
	    ByVal sepP As Double, _
	    ByVal sepT As Double) As Double
	
	    Dim mult As Double
	    mult = 10 ^ (1.769 / oilSG - 1.2308 - 0.00162 * sepT)
	
	    Dim A1 As Double
	    A1 = ((8.088 * sepP + 1.4) * mult) ^ 1.205
	
	    Dim A2 As Double
	    A2 = 2.83 / oilSG - 2.38
	
	    Dim A3 As Double
	    A3 = 0.00047 - 0.000505 / oilSG
	
	    DoEval = 0.178 * A1 * A2 / (1 - A1 * A3)
	
	End Function

End Class
