Public Class FrictionFByColebrook

	Inherits PipeCorrelation

	Public Sub New()
		MyBase.New(pvtFrictionF, "_Colebrook", "")

		Input(pvtDiam, 0, 0, "mm")
		Input(pvtRough, 0, 0, "mm")
		Input(pvtRe, 0, 0)
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtDiam), _
           f.Val(pvtRough), _
           f.Val(pvtRe))

	End Function

	Public Function DoEval( _
	    ByVal diam as Double, _
	    ByVal rough as Double, _
	    ByVal Re as Double) as Double
	    
	    Dim eD# = rough / diam
	    Dim eq As Func(Of Double, Double) = Function(ff) _
	            1.0 / sqrt(ff) + 2 * log(eD / 3.7 + 2.51 / Re / sqrt(ff))        
	    
	    Dim zmin As Double = 0.00001
	    Const zmax As Double = 2
	    Dim tol As Double = 0.000001
	    Const itermax As Double = 100
	    
	    return Solve(eq, zmin, zmax, tol, itermax)
	
	End Function

End Class
