Public Class WaterCoByOsif1988

	Inherits WaterCorrelation

	Public Sub New()
		MyBase.New(pvtWaterCo, "Osif (1988)", "Psia-1")

		Input(pvtP, 1000.7251631617, 19985.4967367658, "Psia")
		Input(pvtT, 199.13, 269.33, "F")
		Input(pvtWaterPbub, 0, 0, "Psia")
		Input(pvtSaltMassPart, 0, 20)
		Input(pvtBg, 0, 0, "m3/m3")
		Input(pvtBw, 0, 0, "m3/m3")
		Input(pvtWaterDensRC, 0, 0, "lb/ft3")
	End Sub

	Protected Overrides Function DoEvaluate(ByRef f As Fluids) As Double

		DoEvaluate = DoEval( _
           f.Val(pvtWaterPbub), _
           f.Val(pvtBw), _
           f.Val(pvtBg), _
           f.Val(pvtSaltMassPart), _
           f.Val(pvtP), _
           f.Val(pvtT), _
           f.Val(pvtWaterDensRC))

	End Function

	Public Function DoEval( _
	    ByVal Pb As Double, _
	    ByVal Bw As Double, _
	    ByVal Bg As Double, _
	    ByVal salinity As Double, _
	    ByVal P As Double, _
	    ByVal T As Double, _
	    ByVal rhoW As Double) As Double
	
	    '%->mg/L
	    Dim s# = 0.01 * salinity * rhoW
	   
	    '- dBw_dp / Bw
	    Dim Cw# = 1 / (7.033 * P + .5415 * s - 537.0 * T + 403300)
	
	    If P < Pb Then
	        Dim B# = 1.01021 * 10 ^ (-2) - 7.44241 * 10 ^ (-5) * T + 3.05553 * 10 ^ (-7) * T ^ 2 - 2.94883 * 10 ^ (-10) * T ^ 3
	        Dim C# = - 10 ^ (-7) * (9.02505 - 0.130237 * T + 8.53425 * 10 ^ (-4) * T ^ 2 - 2.34122 * 10 ^ (-6) * T ^ 3 + 2.37049 * 10 ^ (-9) * T ^ 4)
	
	        Dim dRsw_dp# = (B + 2 * C * P) * Exp(-0.0840655 * salinity * T ^ (-0.285854))
	        DoEval = Cw + Bg / Bw * dRsw_dp
	    Else
	        DoEval = Cw
	    End If
	
	End Function

End Class
